# Python RRN

[![Build Status](https://travis-ci.org/Rainist/rrn.svg?branch=master)](https://travis-ci.org/Rainist/rrn)

A Python library for dealing with [주민등록번호<sub>Resident Registration Number</sub>](https://ko.wikipedia.org/wiki/%EC%A3%BC%EB%AF%BC%EB%93%B1%EB%A1%9D%EB%B2%88%ED%98%B8) including validation, checking correspondence between given RRN and personal information, and so on.
